API Specification
-----------------

This page contains the specification for all classes and methods available in
python-arango.

.. _ArangoClient:

ArangoClient
============

.. autoclass:: arango.client.ArangoClient
    :members:

.. _AsyncDatabase:

AsyncDatabase
=============

.. autoclass:: arango.database.AsyncDatabase
    :inherited-members:
    :members:

.. _AsyncJob:

AsyncJob
========

.. autoclass:: arango.job.AsyncJob
    :members:

.. _AQL:

AQL
====

.. autoclass:: arango.aql.AQL
    :members:

.. _AQLQueryCache:

AQLQueryCache
=============

.. autoclass:: arango.aql.AQLQueryCache
    :members:

.. _Backup:

Backup
======

.. autoclass:: arango.backup.Backup
    :inherited-members:
    :members:

.. _BatchDatabase:

BatchDatabase
=============

.. autoclass:: arango.database.BatchDatabase
    :inherited-members:
    :members:

.. _BatchJob:

BatchJob
========

.. autoclass:: arango.job.BatchJob
    :members:

.. _Cluster:

Cluster
=======

.. autoclass:: arango.cluster.Cluster
    :members:

.. _Collection:

Collection
==========

.. autoclass:: arango.collection.Collection
    :members:

.. _Cursor:

Cursor
======

.. autoclass:: arango.cursor.Cursor
    :members:

.. _DefaultHTTPClient:

DefaultHTTPClient
=================

.. autoclass:: arango.http.DefaultHTTPClient
    :members:

.. _EdgeCollection:

EdgeCollection
==============

.. autoclass:: arango.collection.EdgeCollection
    :members:

.. _Foxx:

Foxx
====

.. autoclass:: arango.foxx.Foxx
    :members:

.. _Graph:

Graph
=====

.. autoclass:: arango.graph.Graph
    :members:

.. _HTTPClient:

HTTPClient
==========

.. autoclass:: arango.http.HTTPClient
    :members:

.. _Pregel:

Pregel
======

.. autoclass:: arango.pregel.Pregel
    :members:

.. _Replication:

Replication
===========

.. autoclass:: arango.replication.Replication
    :members:

.. _Request:

Request
=======

.. autoclass:: arango.request.Request
    :members:

.. _Response:

Response
========

.. autoclass:: arango.response.Response
    :members:

.. _StandardCollection:

StandardCollection
==================

.. autoclass:: arango.collection.StandardCollection
    :inherited-members:
    :members:

.. _StandardDatabase:

StandardDatabase
================

.. autoclass:: arango.database.StandardDatabase
    :inherited-members:
    :members:

.. _TransactionDatabase:

TransactionDatabase
===================

.. autoclass:: arango.database.TransactionDatabase
    :inherited-members:
    :members:

.. _VertexCollection:

VertexCollection
================

.. autoclass:: arango.collection.VertexCollection
    :members:

.. _WriteAheadLog:

WAL
====

.. autoclass:: arango.wal.WAL
    :members:
